@@ -73,10 +73,9 @@ class PyPIRepository(BaseRepository):
         # Use pip's parser for pip.conf management and defaults.
         # General options (find_links, index_url, extra_index_url, trusted_host,
         # and pre) are deferred to pip.
-        self.command: InstallCommand = create_command("install")
-        extra_pip_args = ["--use-deprecated", "legacy-resolver"]
+        self._command: InstallCommand = create_command("install")
 
-        options, _ = self.command.parse_args(pip_args + extra_pip_args)
+        options, _ = self.command.parse_args(pip_args)
         if options.cache_dir:
             options.cache_dir = normalize_path(options.cache_dir)
         options.require_hashes = False
@@ -103,8 +102,7 @@ class PyPIRepository(BaseRepository):
         self._cache_dir = normalize_path(str(cache_dir))
         self._download_dir = os.path.join(self._cache_dir, "pkgs")
 
-        if PIP_VERSION[0] < 22:
-            self._setup_logging()
+        self._setup_logging()
 
     def clear_caches(self) -> None:
         rmtree(self._download_dir, ignore_errors=True)
@@ -121,6 +119,11 @@ class PyPIRepository(BaseRepository):
     def finder(self) -> PackageFinder:
         return self._finder
 
+    @property
+    def command(self) -> InstallCommand:
+        """Return an install command instance."""
+        return self._command
+
     def find_all_candidates(self, req_name: str) -> List[InstallationCandidate]:
         if req_name not in self._available_candidates_cache:
             candidates = self.finder.find_all_candidates(req_name)
@@ -464,6 +467,9 @@ class PyPIRepository(BaseRepository):
             user_log_file=self.options.log,
         )
 
+        if PIP_VERSION[0] >= 22:
+            return
+
         # Sync pip's console handler stream with LogContext.stream
         logger = logging.getLogger()
         for handler in logger.handlers:
